from setuptools import setup

setup(
    name='kegscraper',
    version='v0.1.1',
    packages=['kegscraper'],
    url='https://github.com/BigPotatoPizzaHey/kegscraper/',
    license='',
    author='BigPotatoPizzaHey',
    author_email='',
    description=''
)
